\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{ecn}[2008/08/08v1.0]
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{book}}
\ProcessOptions

\LoadClass{book}
\RequirePackage[T1]{fontenc}
\RequirePackage[latin1]{inputenc}
\RequirePackage[dvips]{graphicx}
\RequirePackage[dvips]{xcolor}
\RequirePackage{fancyhdr}
\RequirePackage{fancybox}
\RequirePackage{setspace}
\RequirePackage{pstricks,pst-text,pst-plot,pst-all}
\usepackage[margin=40pt,font=small,labelfont=bf,justification=centerlast,labelsep=endash]{caption}
\RequirePackage{amsmath}
\RequirePackage{amssymb}
\RequirePackage{amsfonts}
\RequirePackage{subfigure}
\RequirePackage{psfrag}
\RequirePackage{multirow}
\RequirePackage[colorlinks=true,dvips,bookmarks=true]{hyperref}
\hypersetup{pdfauthor={Herv Oudin},pdftitle={Introduction  la mthode des lments finis},citecolor=bleu,bookmarksnumbered=true,linkcolor=bleu}
\RequirePackage{algorithmic}
\RequirePackage{array}
\RequirePackage{eso-pic}
\RequirePackage[frenchb]{babel}
\frenchbsetup{IndentFirst=false}
\addto\captionsfrench{\def\figurename{Figure}}
\addto\captionsfrench{\def\tablename{Tableau}}
\RequirePackage{upgreek}
\RequirePackage{makeidx}

%paisseur des lignes:
\newlength{\epaisseur}
\setlength{\epaisseur}{.3mm}

% dfinition du d romain de drivation
\newcommand{\ud}{\mathrm{d}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%dfinition de l'entte des chapitres
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\@makechapterhead#1{%
\vspace*{-20\p@}%
  {\raggedright\ifnum\c@secnumdepth>\m@ne
  \if@mainmatter
  \raggedleft\Huge\bfseries\thechapter\par\nobreak%
          \vspace*{20pt}%
        \fi%
      \fi%
    \raggedleft\Huge\sc\bfseries #1\par%
    \vspace*{50\p@}%
}}%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%dfinition de l'entte des chapitres non numrots
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\@makeschapterhead#1{%
\vspace*{-20\p@}%
{\parindent\z@\raggedleft\normalfont\interlinepenalty\@M%
\Huge\sc\bfseries #1\par\nobreak\vspace*{50\p@}%
}}%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% dfinition de l'entte de la table des matires
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\renewcommand{\tableofcontents}{\pagestyle{empty}%
\chapter*{\contentsname\vspace*{50\p@}}%
\addcontentsline{toc}{chapter}{\contentsname}%
\markboth{\normalfont\normalsize\sc\textcolor{bleu}{\contentsname}}{}%
\@starttoc{toc}}%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% dfinition de l'index
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\renewenvironment{theindex}{%
\columnseprule \z@
\columnsep 35\p@
\twocolumn[\@makeschapterhead{Index \vspace*{50\p@}}]%
\markboth{\normalfont\normalsize\sc\textcolor{bleu}{Index}}{}
\thispagestyle{plain}\parindent\z@
\parskip\z@ \@plus .3\p@\relax
\let\item\@idxitem
\phantomsection
\addcontentsline{toc}{chapter}{Index}}
{\if@restonecol\onecolumn\else\clearpage\fi}
\renewcommand\@idxitem{\par\hangindent 40\p@}
\renewcommand\subitem{\@idxitem \hspace*{20\p@}}
\renewcommand\subsubitem{\@idxitem \hspace*{30\p@}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% fancyhdr parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newlength\debordementdroit\setlength\debordementdroit{0pt}
\newlength\debordementgauche\setlength\debordementgauche{30pt}
\pagestyle{fancy}
\fancyheadoffset{\debordementdroit}
\fancyfootoffset{\debordementdroit}
\renewcommand{\chaptermark}[1]{\markboth{\normalfont\normalsize\textsc{\textcolor{bleu}{#1}}}{}}
\renewcommand{\sectionmark}[1]{\markright{\normalfont\normalsize\thesection\ #1}{}}
\fancyhf{} \fancyhead[LE,RO]{\normalfont\normalsize\textcolor{bleu}{\thepage}}
\fancyhead[LO]{\itshape{\rightmark}}
\fancyhead[RE]{\itshape{\leftmark}}
\renewcommand{\headrulewidth}{0.5pt}
\addtolength{\headheight}{0.5pt}
\renewcommand{\footrulewidth}{0pt}
\fancypagestyle{plain}{
\fancyhead{}
\renewcommand{\headrulewidth}{0pt}}
\renewcommand{\cleardoublepage}{%
\clearpage\ifodd\c@page\else
\hbox{}
\vspace*{\fill}
\thispagestyle{empty}% <--
\newpage
\fi} 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% dfinition de l'apparence des sections et sous-sections (copie de la classe article)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\renewcommand{\@seccntformat}[1]{\llap{\textcolor{bleu}{\csname the#1\endcsname}\hspace{0.5em}}}

\renewcommand\section{\@startsection {section}{1}{\z@}%
                                   {-3.5ex \@plus -1ex \@minus -.2ex}%
                                   {2.3ex \@plus.2ex}%
                                   {\normalfont\Large\bfseries}}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
                                     {-3.25ex\@plus -1ex \@minus -.2ex}%
                                     {1.5ex \@plus .2ex}%
                                     {\normalfont\large\bfseries}}
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
                                     {-3.25ex\@plus -1ex \@minus -.2ex}%
                                     {1.5ex \@plus .2ex}%
                                     {\normalfont\normalsize\bfseries}}
\renewcommand\paragraph{\@startsection{paragraph}{4}{\z@}%
                                    {3.25ex \@plus1ex \@minus.2ex}%
                                    {-1em}%
                                    {\normalfont\normalsize\bfseries}}
\renewcommand\subparagraph{\@startsection{subparagraph}{5}{\parindent}%
                                       {3.25ex \@plus1ex \@minus .2ex}%
                                       {-1em}%
                                      {\normalfont\normalsize\bfseries}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% dfinition du comportement des guillemets
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\catcode`\=\active
\catcode`\=\active
\def{\og\ignorespaces}
\def{\fg}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% enlve l'entte des pages de fin de chapitre si nombre de pages impair
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\renewcommand{\cleardoublepage}{%
\clearpage\ifodd\c@page\else
\hbox{}
\vspace*{\fill}
\thispagestyle{empty}
\newpage
\fi
}
